<?php

declare(strict_types=1);

/*
 * This file is part of the package itzbund/gsb-metadata-cleaner of the GSB 11 Project by ITZBund.
 *
 * Copyright (C) 2023 - 2024 Bundesrepublik Deutschland, vertreten durch das
 * BMI/ITZBund. Author: Ole Hartwig, Patrick Schriner
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace ITZBund\GsbMetadataCleaner\EventListener;

use ITZBund\GsbMetadataCleaner\Service\ExifToolService;
use Psr\Log\LoggerInterface;
use Psr\Log\LogLevel;
use TYPO3\CMS\Core\Resource\Event\AfterFileAddedEvent;

/**
 * This listener passes the absolute file path to the exiftool utility
 */
class BeforeFileAddedEventListener
{
    public function __construct(
        private readonly ExifToolService $exifToolService,
        private readonly LoggerInterface $logger
    ) {}

    public function __invoke(AfterFileAddedEvent $event): void
    {
        $file = $event->getFile();
        if ($this->exifToolService->canProcessFile($file)) {
            try {
                $this->exifToolService->removeMetadata($file);
            } catch (\Exception $re) {
                $this->logger->log(LogLevel::ERROR, $re->getMessage());
            }
        }
    }
}
